@@ -4,7 +4,7 @@ A module to wrap (non-Windows) archive calls
 .. versionadded:: 2014.1.0
 """
 
-import contextlib  # For < 2.7 compat
+import contextlib
 import copy
 import errno
 import glob
@@ -27,12 +27,6 @@ import salt.utils.stringutils
 import salt.utils.templates
 from salt.exceptions import CommandExecutionError, SaltInvocationError
 
-try:
-    from shlex import quote as _quote  # pylint: disable=E0611
-except ImportError:
-    from pipes import quote as _quote
-
-
 try:
     import rarfile
 
@@ -61,10 +55,11 @@ def list_(
     verbose=False,
     saltenv="base",
     source_hash=None,
+    use_etag=False,
 ):
     """
     .. versionadded:: 2016.11.0
-    .. versionchanged:: 2016.11.2
+    .. versionchanged:: 2016.11.2,3005
         The rarfile_ Python module is now supported for listing the contents of
         rar archives. This is necessary on minions with older releases of the
         ``rar`` CLI tool, which do not support listing the contents in a
@@ -158,6 +153,15 @@ def list_(
 
         .. versionadded:: 2018.3.0
 
+    use_etag
+        If ``True``, remote http/https file sources will attempt to use the
+        ETag header to determine if the remote file needs to be downloaded.
+        This provides a lightweight mechanism for promptly refreshing files
+        changed on a web server without requiring a full hash comparison via
+        the ``source_hash`` parameter.
+
+        .. versionadded:: 3005
+
     .. _tarfile: https://docs.python.org/2/library/tarfile.html
     .. _xz: http://tukaani.org/xz/
 
@@ -213,7 +217,7 @@ def list_(
                     # Guard against shell injection
                     try:
                         decompress_cmd = [
-                            _quote(x) for x in shlex.split(decompress_cmd)
+                            shlex.quote(x) for x in shlex.split(decompress_cmd)
                         ]
                     except AttributeError:
                         raise CommandExecutionError("Invalid CLI options")
@@ -327,7 +331,9 @@ def list_(
                 )
         return dirs, files, []
 
-    cached = __salt__["cp.cache_file"](name, saltenv, source_hash=source_hash)
+    cached = __salt__["cp.cache_file"](
+        name, saltenv, source_hash=source_hash, use_etag=use_etag
+    )
     if not cached:
         raise CommandExecutionError("Failed to cache {}".format(name))
 
@@ -419,7 +425,15 @@ def list_(
                 "files": sorted(salt.utils.data.decode_list(files)),
                 "links": sorted(salt.utils.data.decode_list(links)),
             }
-            ret["top_level_dirs"] = [x for x in ret["dirs"] if x.count("/") == 1]
+            top_level_dirs = [x for x in ret["dirs"] if x.count("/") == 1]
+            # the common_prefix logic handles scenarios where the TLD
+            # isn't listed as an archive member on its own
+            common_prefix = os.path.commonprefix(ret["dirs"])
+            if "/" in common_prefix:
+                common_prefix = common_prefix.split("/")[0] + "/"
+                if common_prefix not in top_level_dirs:
+                    top_level_dirs.append(common_prefix)
+            ret["top_level_dirs"] = top_level_dirs
             ret["top_level_files"] = [x for x in ret["files"] if x.count("/") == 0]
             ret["top_level_links"] = [x for x in ret["links"] if x.count("/") == 0]
         else:
@@ -457,7 +471,7 @@ def _expand_sources(sources):
         return []
     if isinstance(sources, str):
         sources = [x.strip() for x in sources.split(",")]
-    elif isinstance(sources, (float, (int,))):
+    elif isinstance(sources, (float, int)):
         sources = [str(sources)]
     return [path for source in sources for path in _glob(source)]
 
@@ -675,7 +689,6 @@ def cmd_zip(zip_file, sources, template=None, cwd=None, runas=None):
 
         .. versionadded:: 2015.5.0
 
-
     CLI Example:
 
     .. code-block:: bash
@@ -913,7 +926,6 @@ def cmd_unzip(
 
         .. versionadded:: 2016.11.0
 
-
     CLI Example:
 
     .. code-block:: bash
@@ -922,7 +934,7 @@ def cmd_unzip(
     """
     if isinstance(excludes, str):
         excludes = [x.strip() for x in excludes.split(",")]
-    elif isinstance(excludes, (float, (int,))):
+    elif isinstance(excludes, (float, int)):
         excludes = [str(excludes)]
 
     cmd = ["unzip"]
@@ -1068,7 +1080,7 @@ def unzip(
 
             if isinstance(excludes, str):
                 excludes = [x.strip() for x in excludes.split(",")]
-            elif isinstance(excludes, (float, (int,))):
+            elif isinstance(excludes, (float, int)):
                 excludes = [str(excludes)]
 
             cleaned_files.extend([x for x in files if x not in excludes])
@@ -1115,9 +1127,10 @@ def unzip(
     return _trim_files(cleaned_files, trim_output)
 
 
-def is_encrypted(name, clean=False, saltenv="base", source_hash=None):
+def is_encrypted(name, clean=False, saltenv="base", source_hash=None, use_etag=False):
     """
     .. versionadded:: 2016.11.0
+    .. versionchanged:: 3005
 
     Returns ``True`` if the zip archive is password-protected, ``False`` if
     not. If the specified file is not a ZIP archive, an error will be raised.
@@ -1147,6 +1160,15 @@ def is_encrypted(name, clean=False, saltenv="base", source_hash=None):
 
         .. versionadded:: 2018.3.0
 
+    use_etag
+        If ``True``, remote http/https file sources will attempt to use the
+        ETag header to determine if the remote file needs to be downloaded.
+        This provides a lightweight mechanism for promptly refreshing files
+        changed on a web server without requiring a full hash comparison via
+        the ``source_hash`` parameter.
+
+        .. versionadded:: 3005
+
     CLI Examples:
 
     .. code-block:: bash
@@ -1158,7 +1180,9 @@ def is_encrypted(name, clean=False, saltenv="base", source_hash=None):
             salt '*' archive.is_encrypted https://domain.tld/myfile.zip source_hash=f1d2d2f924e986ac86fdf7b36c94bcdf32beec15
             salt '*' archive.is_encrypted ftp://10.1.2.3/foo.zip
     """
-    cached = __salt__["cp.cache_file"](name, saltenv, source_hash=source_hash)
+    cached = __salt__["cp.cache_file"](
+        name, saltenv, source_hash=source_hash, use_etag=use_etag
+    )
     if not cached:
         raise CommandExecutionError("Failed to cache {}".format(name))
 
@@ -1302,8 +1326,7 @@ def _render_filenames(filenames, zip_file, saltenv, template):
     # render the path as a template using path_template_engine as the engine
     if template not in salt.utils.templates.TEMPLATE_REGISTRY:
         raise CommandExecutionError(
-            "Attempted to render file paths with unavailable engine "
-            "{}".format(template)
+            "Attempted to render file paths with unavailable engine {}".format(template)
         )
 
     kwargs = {}
