@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-'''
+"""
     :copyright: Copyright 2017 by the SaltStack Team, see AUTHORS for more details.
     :license: Apache 2.0, see LICENSE for more details.
 
@@ -9,28 +8,22 @@
 
     Version parsing based on distutils.version which works under python 3
     because on python 3 you can no longer compare strings against integers.
-'''
-
-# Import Python libs
-from __future__ import absolute_import, print_function, unicode_literals
-import logging
-import numbers
-import sys
-import warnings
+"""
 import datetime
 import inspect
-import contextlib
-# pylint: disable=blacklisted-module,no-name-in-module
-from distutils.version import StrictVersion as _StrictVersion
+import logging
+import numbers
+import os
+import sys
+import warnings
+
+# pylint: disable=blacklisted-module
 from distutils.version import LooseVersion as _LooseVersion
-# pylint: enable=blacklisted-module,no-name-in-module
+from distutils.version import StrictVersion as _StrictVersion
 
-# Import Salt libs
+# pylint: enable=blacklisted-module
 import salt.version
 
-# Import 3rd-party libs
-from salt.ext import six
-
 log = logging.getLogger(__name__)
 
 
@@ -39,82 +32,68 @@ class StrictVersion(_StrictVersion):
         _StrictVersion.parse(self, vstring)
 
     def _cmp(self, other):
-        if isinstance(other, six.string_types):
+        if isinstance(other, str):
             other = StrictVersion(other)
         return _StrictVersion._cmp(self, other)
 
 
 class LooseVersion(_LooseVersion):
-
     def parse(self, vstring):
         _LooseVersion.parse(self, vstring)
 
-        if six.PY3:
-            # Convert every part of the version to string in order to be able to compare
-            self._str_version = [
-                six.text_type(vp).zfill(8) if isinstance(vp, int) else vp for vp in self.version]
+        # Convert every part of the version to string in order to be able to compare
+        self._str_version = [
+            str(vp).zfill(8) if isinstance(vp, int) else vp for vp in self.version
+        ]
 
-    if six.PY3:
-        def _cmp(self, other):
-            if isinstance(other, six.string_types):
-                other = LooseVersion(other)
+    def _cmp(self, other):
+        if isinstance(other, str):
+            other = LooseVersion(other)
 
-            string_in_version = False
-            for part in self.version + other.version:
-                if not isinstance(part, int):
-                    string_in_version = True
-                    break
+        string_in_version = False
+        for part in self.version + other.version:
+            if not isinstance(part, int):
+                string_in_version = True
+                break
 
-            if string_in_version is False:
-                return _LooseVersion._cmp(self, other)
+        if string_in_version is False:
+            return _LooseVersion._cmp(self, other)
 
-            # If we reached this far, it means at least a part of the version contains a string
-            # In python 3, strings and integers are not comparable
-            if self._str_version == other._str_version:
-                return 0
-            if self._str_version < other._str_version:
-                return -1
-            if self._str_version > other._str_version:
-                return 1
+        # If we reached this far, it means at least a part of the version contains a string
+        # In python 3, strings and integers are not comparable
+        if self._str_version == other._str_version:
+            return 0
+        if self._str_version < other._str_version:
+            return -1
+        if self._str_version > other._str_version:
+            return 1
 
 
 def _format_warning(message, category, filename, lineno, line=None):
-    '''
+    """
     Replacement for warnings.formatwarning that disables the echoing of
     the 'line' parameter.
-    '''
-    return '{}:{}: {}: {}\n'.format(
-        filename, lineno, category.__name__, message
-    )
+    """
+    return "{}:{}: {}: {}\n".format(filename, lineno, category.__name__, message)
 
 
-@contextlib.contextmanager
-def _patched_format_warning():
-    if six.PY2:
-        saved = warnings.formatwarning
-        warnings.formatwarning = _format_warning
-        yield
-        warnings.formatwarning = saved
-    else:
-        # Under Py3 we no longer have to patch warnings.formatwarning
-        yield
-
-
-def warn_until(version,
-               message,
-               category=DeprecationWarning,
-               stacklevel=None,
-               _version_info_=None,
-               _dont_call_warnings=False):
-    '''
+def warn_until(
+    version,
+    message,
+    category=DeprecationWarning,
+    stacklevel=None,
+    _version_info_=None,
+    _dont_call_warnings=False,
+):
+    """
     Helper function to raise a warning, by default, a ``DeprecationWarning``,
     until the provided ``version``, after which, a ``RuntimeError`` will
     be raised to remind the developers to remove the warning because the
     target version has been reached.
 
-    :param version: The version info or name after which the warning becomes a
-                    ``RuntimeError``. For example ``(0, 17)`` or ``Hydrogen``
-                    or an instance of :class:`salt.version.SaltStackVersion`.
+    :param version: The version info or name after which the warning becomes a ``RuntimeError``.
+                    For example ``(2019, 2)``, ``3000``, ``Hydrogen`` or an instance of
+                    :class:`salt.version.SaltStackVersion` or :class:`salt.version.SaltVersion`.
     :param message: The warning message to be displayed.
     :param category: The warning class to be thrown, by default
                      ``DeprecationWarning``
@@ -127,18 +106,28 @@ def warn_until(version,
                                 functionality until the actual error is to be
                                 issued. When we're only after the salt version
                                 checks to raise a ``RuntimeError``.
-    '''
-    if not isinstance(version, (tuple,
-                                six.string_types,
-                                salt.version.SaltStackVersion)):
-        raise RuntimeError(
-            'The \'version\' argument should be passed as a tuple, string or '
-            'an instance of \'salt.version.SaltStackVersion\'.'
-        )
+    """
+    if isinstance(version, salt.version.SaltVersion):
+        version = salt.version.SaltStackVersion(*version.info)
+    elif isinstance(version, int):
+        version = salt.version.SaltStackVersion(version)
     elif isinstance(version, tuple):
         version = salt.version.SaltStackVersion(*version)
-    elif isinstance(version, six.string_types):
+    elif isinstance(version, str):
+        if version.lower() not in salt.version.SaltStackVersion.LNAMES:
+            raise RuntimeError(
+                "Incorrect spelling for the release name in the warn_utils "
+                "call. Expecting one of these release names: {}".format(
+                    [vs.name for vs in salt.version.SaltVersionsInfo.versions()]
+                )
+            )
         version = salt.version.SaltStackVersion.from_name(version)
+    elif not isinstance(version, salt.version.SaltStackVersion):
+        raise RuntimeError(
+            "The 'version' argument should be passed as a tuple, integer, string or "
+            "an instance of 'salt.version.SaltVersion' or "
+            "'salt.version.SaltStackVersion'."
+        )
 
     if stacklevel is None:
         # Attribute the warning to the calling function, not to warn_until()
@@ -151,34 +140,42 @@ def warn_until(version,
 
     if _version_ >= version:
         caller = inspect.getframeinfo(sys._getframe(stacklevel - 1))
-        raise RuntimeError(
-            'The warning triggered on filename \'{filename}\', line number '
-            '{lineno}, is supposed to be shown until version '
-            '{until_version} is released. Current version is now '
-            '{salt_version}. Please remove the warning.'.format(
+        deprecated_message = (
+            "The warning triggered on filename '{filename}', line number "
+            "{lineno}, is supposed to be shown until version "
+            "{until_version} is released. Current version is now "
+            "{salt_version}. Please remove the warning.".format(
                 filename=caller.filename,
                 lineno=caller.lineno,
                 until_version=version.formatted_version,
-                salt_version=_version_.formatted_version
-            ),
+                salt_version=_version_.formatted_version,
+            )
         )
+        if os.environ.get("RAISE_DEPRECATIONS_RUNTIME_ERRORS", "0") == "1":
+            # We don't raise RuntimeError by default since that can break
+            # users systems. We do however want to raise them in a CI context.
+            raise RuntimeError(deprecated_message)
+        # Otherwise, print the deprecated message to STDERR
+        sys.stderr.write(f"\n{deprecated_message}\n")
+        sys.stderr.flush()
 
     if _dont_call_warnings is False:
-        with _patched_format_warning():
-            warnings.warn(
-                message.format(version=version.formatted_version),
-                category,
-                stacklevel=stacklevel
-            )
+        warnings.warn(
+            message.format(version=version.formatted_version),
+            category,
+            stacklevel=stacklevel,
+        )
 
 
-def warn_until_date(date,
-                    message,
-                    category=DeprecationWarning,
-                    stacklevel=None,
-                    _current_date=None,
-                    _dont_call_warnings=False):
-    '''
+def warn_until_date(
+    date,
+    message,
+    category=DeprecationWarning,
+    stacklevel=None,
+    _current_date=None,
+    _dont_call_warnings=False,
+):
+    """
     Helper function to raise a warning, by default, a ``DeprecationWarning``,
     until the provided ``date``, after which, a ``RuntimeError`` will
     be raised to remind the developers to remove the warning because the
@@ -194,17 +191,17 @@ def warn_until_date(date,
                                 functionality until the actual error is to be
                                 issued. When we're only after the date
                                 checks to raise a ``RuntimeError``.
-    '''
-    _strptime_fmt = '%Y%m%d'
-    if not isinstance(date, (six.string_types, datetime.date, datetime.datetime)):
+    """
+    _strptime_fmt = "%Y%m%d"
+    if not isinstance(date, (str, datetime.date, datetime.datetime)):
         raise RuntimeError(
-            'The \'date\' argument should be passed as a \'datetime.date()\' or '
-            '\'datetime.datetime()\' objects or as string parserable by '
-            '\'datetime.datetime.strptime()\' with the following format \'{}\'.'.format(
+            "The 'date' argument should be passed as a 'datetime.date()' or "
+            "'datetime.datetime()' objects or as string parserable by "
+            "'datetime.datetime.strptime()' with the following format '{}'.".format(
                 _strptime_fmt
             )
         )
-    elif isinstance(date, six.text_type):
+    elif isinstance(date, str):
         date = datetime.datetime.strptime(date, _strptime_fmt)
 
     # We're really not interested in the time
@@ -218,41 +215,43 @@ def warn_until_date(date,
     today = _current_date or datetime.datetime.utcnow().date()
     if today >= date:
         caller = inspect.getframeinfo(sys._getframe(stacklevel - 1))
-        raise RuntimeError(
-            '{message} This warning(now exception) triggered on '
-            'filename \'{filename}\', line number {lineno}, is '
-            'supposed to be shown until {date}. Today is {today}. '
-            'Please remove the warning.'.format(
-                message=message.format(
-                    date=date.isoformat(),
-                    today=today.isoformat()
-                ),
+        deprecated_message = (
+            "{message} This warning(now exception) triggered on "
+            "filename '{filename}', line number {lineno}, is "
+            "supposed to be shown until {date}. Today is {today}. "
+            "Please remove the warning.".format(
+                message=message.format(date=date.isoformat(), today=today.isoformat()),
                 filename=caller.filename,
                 lineno=caller.lineno,
                 date=date.isoformat(),
                 today=today.isoformat(),
             ),
         )
+        if os.environ.get("RAISE_DEPRECATIONS_RUNTIME_ERRORS", "0") == "1":
+            # We don't raise RuntimeError by default since that can break
+            # users systems. We do however want to raise them in a CI context.
+            raise RuntimeError(deprecated_message)
+        # Otherwise, print the deprecated message to STDERR
+        sys.stderr.write(f"\n{deprecated_message}\n")
+        sys.stderr.flush()
 
     if _dont_call_warnings is False:
-        with _patched_format_warning():
-            warnings.warn(
-                message.format(
-                    date=date.isoformat(),
-                    today=today.isoformat()
-                ),
-                category,
-                stacklevel=stacklevel
-            )
+        warnings.warn(
+            message.format(date=date.isoformat(), today=today.isoformat()),
+            category,
+            stacklevel=stacklevel,
+        )
 
 
-def kwargs_warn_until(kwargs,
-                      version,
-                      category=DeprecationWarning,
-                      stacklevel=None,
-                      _version_info_=None,
-                      _dont_call_warnings=False):
-    '''
+def kwargs_warn_until(
+    kwargs,
+    version,
+    category=DeprecationWarning,
+    stacklevel=None,
+    _version_info_=None,
+    _dont_call_warnings=False,
+):
+    """
     Helper function to raise a warning (by default, a ``DeprecationWarning``)
     when unhandled keyword arguments are passed to function, until the
     provided ``version_info``, after which, a ``RuntimeError`` will be raised
@@ -279,17 +278,15 @@ def kwargs_warn_until(kwargs,
                                 functionality until the actual error is to be
                                 issued. When we're only after the salt version
                                 checks to raise a ``RuntimeError``.
-    '''
-    if not isinstance(version, (tuple,
-                                six.string_types,
-                                salt.version.SaltStackVersion)):
+    """
+    if not isinstance(version, (tuple, str, salt.version.SaltStackVersion)):
         raise RuntimeError(
-            'The \'version\' argument should be passed as a tuple, string or '
-            'an instance of \'salt.version.SaltStackVersion\'.'
+            "The 'version' argument should be passed as a tuple, string or "
+            "an instance of 'salt.version.SaltStackVersion'."
         )
     elif isinstance(version, tuple):
         version = salt.version.SaltStackVersion(*version)
-    elif isinstance(version, six.string_types):
+    elif isinstance(version, str):
         version = salt.version.SaltStackVersion.from_name(version)
 
     if stacklevel is None:
@@ -303,29 +300,29 @@ def kwargs_warn_until(kwargs,
     _version_ = salt.version.SaltStackVersion(*_version_info_)
 
     if kwargs or _version_.info >= version.info:
-        arg_names = ', '.join('\'{0}\''.format(key) for key in kwargs)
+        arg_names = ", ".join("'{}'".format(key) for key in kwargs)
         warn_until(
             version,
-            message='The following parameter(s) have been deprecated and '
-                    'will be removed in \'{0}\': {1}.'.format(version.string,
-                                                              arg_names),
+            message=(
+                "The following parameter(s) have been deprecated and "
+                "will be removed in '{}': {}.".format(version.string, arg_names)
+            ),
             category=category,
             stacklevel=stacklevel,
             _version_info_=_version_.info,
-            _dont_call_warnings=_dont_call_warnings
+            _dont_call_warnings=_dont_call_warnings,
         )
 
 
 def version_cmp(pkg1, pkg2, ignore_epoch=False):
-    '''
+    """
     Compares two version strings using salt.utils.versions.LooseVersion. This
     is a fallback for providers which don't have a version comparison utility
     built into them.  Return -1 if version1 < version2, 0 if version1 ==
     version2, and 1 if version1 > version2. Return None if there was a problem
     making the comparison.
-    '''
-    normalize = lambda x: six.text_type(x).split(':', 1)[-1] \
-                if ignore_epoch else six.text_type(x)
+    """
+    normalize = lambda x: str(x).split(":", 1)[-1] if ignore_epoch else str(x)
     pkg1 = normalize(pkg1)
     pkg2 = normalize(pkg2)
 
@@ -342,15 +339,14 @@ def version_cmp(pkg1, pkg2, ignore_epoch=False):
     return None
 
 
-def compare(ver1='', oper='==', ver2='', cmp_func=None, ignore_epoch=False):
-    '''
+def compare(ver1="", oper="==", ver2="", cmp_func=None, ignore_epoch=False):
+    """
     Compares two version numbers. Accepts a custom function to perform the
     cmp-style version comparison, otherwise uses version_cmp().
-    '''
-    cmp_map = {'<': (-1,), '<=': (-1, 0), '==': (0,),
-               '>=': (0, 1), '>': (1,)}
-    if oper not in ('!=',) and oper not in cmp_map:
-        log.error('Invalid operator \'%s\' for version comparison', oper)
+    """
+    cmp_map = {"<": (-1,), "<=": (-1, 0), "==": (0,), ">=": (0, 1), ">": (1,)}
+    if oper not in ("!=",) and oper not in cmp_map:
+        log.error("Invalid operator '%s' for version comparison", oper)
         return False
 
     if cmp_func is None:
@@ -362,12 +358,11 @@ def compare(ver1='', oper='==', ver2='', cmp_func=None, ignore_epoch=False):
 
     # Check if integer/long
     if not isinstance(cmp_result, numbers.Integral):
-        log.error('The version comparison function did not return an '
-                  'integer/long.')
+        log.error("The version comparison function did not return an integer/long.")
         return False
 
-    if oper == '!=':
-        return cmp_result not in cmp_map['==']
+    if oper == "!=":
+        return cmp_result not in cmp_map["=="]
     else:
         # Gracefully handle cmp_result not in (-1, 0, 1).
         if cmp_result < -1:
@@ -378,12 +373,10 @@ def compare(ver1='', oper='==', ver2='', cmp_func=None, ignore_epoch=False):
         return cmp_result in cmp_map[oper]
 
 
-def check_boto_reqs(boto_ver=None,
-                    boto3_ver=None,
-                    botocore_ver=None,
-                    check_boto=True,
-                    check_boto3=True):
-    '''
+def check_boto_reqs(
+    boto_ver=None, boto3_ver=None, botocore_ver=None, check_boto=True, check_boto3=True
+):
+    """
     Checks for the version of various required boto libs in one central location. Most
     boto states and modules rely on a single version of the boto, boto3, or botocore libs.
     However, some require newer versions of any of these dependencies. This function allows
@@ -409,26 +402,28 @@ def check_boto_reqs(boto_ver=None,
         Boolean defining whether or not to check for boto3 (and therefore botocore) deps.
         This defaults to ``True`` as most boto modules/states rely on boto3/botocore, but
         some do not.
-    '''
+    """
     if check_boto is True:
         try:
             # Late import so we can only load these for this function
             import boto
+
             has_boto = True
         except ImportError:
             has_boto = False
 
         if boto_ver is None:
-            boto_ver = '2.0.0'
+            boto_ver = "2.0.0"
 
         if not has_boto or version_cmp(boto.__version__, boto_ver) == -1:
-            return False, 'A minimum version of boto {0} is required.'.format(boto_ver)
+            return False, "A minimum version of boto {} is required.".format(boto_ver)
 
     if check_boto3 is True:
         try:
             # Late import so we can only load these for this function
             import boto3
             import botocore
+
             has_boto3 = True
         except ImportError:
             has_boto3 = False
@@ -436,13 +431,19 @@ def check_boto_reqs(boto_ver=None,
         # boto_s3_bucket module requires boto3 1.2.6 and botocore 1.3.23 for
         # idempotent ACL operations via the fix in https://github.com/boto/boto3/issues/390
         if boto3_ver is None:
-            boto3_ver = '1.2.6'
+            boto3_ver = "1.2.6"
         if botocore_ver is None:
-            botocore_ver = '1.3.23'
+            botocore_ver = "1.3.23"
 
         if not has_boto3 or version_cmp(boto3.__version__, boto3_ver) == -1:
-            return False, 'A minimum version of boto3 {0} is required.'.format(boto3_ver)
+            return (
+                False,
+                "A minimum version of boto3 {} is required.".format(boto3_ver),
+            )
         elif version_cmp(botocore.__version__, botocore_ver) == -1:
-            return False, 'A minimum version of botocore {0} is required'.format(botocore_ver)
+            return (
+                False,
+                "A minimum version of botocore {} is required".format(botocore_ver),
+            )
 
     return True
