@@ -1,22 +1,18 @@
-# -*- coding: utf-8 -*-
-
 """
 Test the ssh module
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import os
 import shutil
 
 import pytest
+import requests
 import salt.utils.files
 import salt.utils.platform
-from salt.ext.tornado.httpclient import HTTPClient
 from tests.support.case import ModuleCase
-from tests.support.helpers import skip_if_binaries_missing, slowTest
 from tests.support.runtests import RUNTIME_VARS
 
-GITHUB_FINGERPRINT = "9d:38:5b:83:a9:17:52:92:56:1a:5e:c4:d4:81:8e:0a:ca:51:a2:64:f1:74:20:11:2e:f8:8a:c3:a1:39:49:8f"
+GITHUB_FINGERPRINT = "b8:d8:95:ce:d9:2c:0a:c0:e1:71:cd:2e:f5:ef:01:ba:34:17:55:4a:4a:64:80:d3:31:cc:c2:be:3d:ed:0f:6b"
 
 
 def check_status():
@@ -24,13 +20,13 @@ def check_status():
     Check the status of Github for remote operations
     """
     try:
-        return HTTPClient().fetch("http://github.com").code == 200
+        return requests.get("https://github.com").status_code == 200
     except Exception:  # pylint: disable=broad-except
         return False
 
 
-@skip_if_binaries_missing(["ssh", "ssh-keygen"], check_all=True)
 @pytest.mark.windows_whitelisted
+@pytest.mark.skip_if_binaries_missing("ssh", "ssh-keygen", check_all=True)
 class SSHModuleTest(ModuleCase):
     """
     Test the ssh module
@@ -48,13 +44,13 @@ class SSHModuleTest(ModuleCase):
         """
         if not check_status():
             self.skipTest("External source, github.com is down")
-        super(SSHModuleTest, self).setUp()
+        super().setUp()
         if not os.path.isdir(self.subsalt_dir):
             os.makedirs(self.subsalt_dir)
 
-        ssh_raw_path = os.path.join(RUNTIME_VARS.FILES, "ssh", "raw")
-        with salt.utils.files.fopen(ssh_raw_path) as fd:
-            self.key = fd.read().strip()
+        known_hosts_file = os.path.join(RUNTIME_VARS.FILES, "ssh", "known_hosts")
+        with salt.utils.files.fopen(known_hosts_file) as fd:
+            self.key = fd.read().strip().splitlines()[0].split()[-1]
 
     def tearDown(self):
         """
@@ -62,10 +58,10 @@ class SSHModuleTest(ModuleCase):
         """
         if os.path.isdir(self.subsalt_dir):
             shutil.rmtree(self.subsalt_dir)
-        super(SSHModuleTest, self).tearDown()
+        super().tearDown()
         del self.key
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_auth_keys(self):
         """
         test ssh.auth_keys
@@ -89,10 +85,10 @@ class SSHModuleTest(ModuleCase):
             self.assertEqual(key_data["fingerprint"], GITHUB_FINGERPRINT)
         except AssertionError as exc:
             raise AssertionError(
-                "AssertionError: {0}. Function returned: {1}".format(exc, ret)
+                "AssertionError: {}. Function returned: {}".format(exc, ret)
             )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_bad_enctype(self):
         """
         test to make sure that bad key encoding types don't generate an
@@ -111,7 +107,7 @@ class SSHModuleTest(ModuleCase):
         # user will get an indicator of what went wrong.
         self.assertEqual(len(list(ret.items())), 0)  # Zero keys found
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_get_known_host_entries(self):
         """
         Check that known host information is returned from ~/.ssh/config
@@ -128,10 +124,14 @@ class SSHModuleTest(ModuleCase):
             self.assertEqual(ret["fingerprint"], GITHUB_FINGERPRINT)
         except AssertionError as exc:
             raise AssertionError(
-                "AssertionError: {0}. Function returned: {1}".format(exc, ret)
+                "AssertionError: {}. Function returned: {}".format(exc, ret)
             )
 
-    @slowTest
+    @pytest.mark.skipif(
+        salt.utils.platform.is_photonos() is True,
+        reason="Skip on PhotonOS.  Attempting to receive the SSH key from Github, using RSA keys which are disabled.",
+    )
+    @pytest.mark.slow_test
     def test_recv_known_host_entries(self):
         """
         Check that known host information is returned from remote host
@@ -146,10 +146,10 @@ class SSHModuleTest(ModuleCase):
             self.assertEqual(ret[0]["fingerprint"], GITHUB_FINGERPRINT)
         except AssertionError as exc:
             raise AssertionError(
-                "AssertionError: {0}. Function returned: {1}".format(exc, ret)
+                "AssertionError: {}. Function returned: {}".format(exc, ret)
             )
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_check_known_host_add(self):
         """
         Check known hosts by its fingerprint. File needs to be updated
@@ -159,7 +159,7 @@ class SSHModuleTest(ModuleCase):
         ret = self.run_function("ssh.check_known_host", arg, **kwargs)
         self.assertEqual(ret, "add")
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_check_known_host_update(self):
         """
         ssh.check_known_host update verification
@@ -178,7 +178,7 @@ class SSHModuleTest(ModuleCase):
         ret = self.run_function("ssh.check_known_host", arg, **dict(kwargs, key="YQ=="))
         self.assertEqual(ret, "update")
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_check_known_host_exists(self):
         """
         Verify check_known_host_exists
@@ -199,7 +199,7 @@ class SSHModuleTest(ModuleCase):
         )
         self.assertEqual(ret, "exists")
 
-    @slowTest
+    @pytest.mark.slow_test
     def test_rm_known_host(self):
         """
         ssh.rm_known_host
@@ -218,7 +218,11 @@ class SSHModuleTest(ModuleCase):
         ret = self.run_function("ssh.check_known_host", arg, **kwargs)
         self.assertEqual(ret, "add")
 
-    @slowTest
+    @pytest.mark.skipif(
+        salt.utils.platform.is_photonos() is True,
+        reason="Skip on PhotonOS.  Attempting to receive the SSH key from Github, using RSA keys which are disabled.",
+    )
+    @pytest.mark.slow_test
     def test_set_known_host(self):
         """
         ssh.set_known_host
@@ -236,7 +240,7 @@ class SSHModuleTest(ModuleCase):
             self.assertEqual(ret["new"][0]["fingerprint"], GITHUB_FINGERPRINT)
         except AssertionError as exc:
             raise AssertionError(
-                "AssertionError: {0}. Function returned: {1}".format(exc, ret)
+                "AssertionError: {}. Function returned: {}".format(exc, ret)
             )
         # check that item does exist
         ret = self.run_function(
@@ -248,7 +252,7 @@ class SSHModuleTest(ModuleCase):
             self.assertEqual(ret["fingerprint"], GITHUB_FINGERPRINT)
         except AssertionError as exc:
             raise AssertionError(
-                "AssertionError: {0}. Function returned: {1}".format(exc, ret)
+                "AssertionError: {}. Function returned: {}".format(exc, ret)
             )
         # add the same item once again
         ret = self.run_function(
@@ -258,5 +262,5 @@ class SSHModuleTest(ModuleCase):
             self.assertEqual(ret["status"], "exists")
         except AssertionError as exc:
             raise AssertionError(
-                "AssertionError: {0}. Function returned: {1}".format(exc, ret)
+                "AssertionError: {}. Function returned: {}".format(exc, ret)
             )
