@@ -1,24 +1,17 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, unicode_literals
-
 import inspect
-import io
 import logging
 import os
 import socket
 import subprocess
-
-# Service manager imports
 import sys
 import textwrap
 import threading
 import time
 import traceback
 
-import salt.ext.six
 import salt.utils.files
 import salt.utils.win_runas
-import yaml
+import salt.utils.yaml
 from tests.support.case import ModuleCase
 from tests.support.helpers import with_system_user
 from tests.support.mock import Mock
@@ -192,8 +185,6 @@ def service_class_factory(
 ):
     frm = inspect.stack()[1]
     mod = inspect.getmodule(frm[0])
-    if salt.ext.six.PY2:
-        cls_name = cls_name.encode()
     return type(
         cls_name,
         (_ServiceManager, object),
@@ -243,7 +234,7 @@ def target(service, *args, **kwargs):
         )
 
     service.log_info("win_runas returned %s" % ret)
-    with open(OUTPUT, 'w') as fp:
+    with salt.utils.files.fopen(OUTPUT, 'w') as fp:
         yaml.dump(ret, fp)
     service.log_info("target stop")
 
@@ -283,7 +274,7 @@ def wait_for_service(name, timeout=200):
 class RunAsTest(ModuleCase):
     @classmethod
     def setUpClass(cls):
-        super(RunAsTest, cls).setUpClass()
+        super().setUpClass()
         cls.hostname = socket.gethostname()
 
     @with_system_user(
@@ -601,7 +592,10 @@ class RunAsTest(ModuleCase):
         groups=["Administrators"],
     )
     def test_runas_powershell_remoting_admin(self, username):
-        psrp_wrap = "powershell Invoke-Command -ComputerName {} -ScriptBlock {{ {} }}; exit $LASTEXITCODE"
+        psrp_wrap = (
+            "powershell Invoke-Command -ComputerName {} -ScriptBlock {{ {} }}; exit"
+            " $LASTEXITCODE"
+        )
         runaspy = textwrap.dedent(
             """
         import sys
@@ -628,7 +622,10 @@ class RunAsTest(ModuleCase):
         groups=["Administrators"],
     )
     def test_runas_powershell_remoting_admin_no_pass(self, username):
-        psrp_wrap = "powershell Invoke-Command -ComputerName {} -ScriptBlock {{ {} }}; exit $LASTEXITCODE"
+        psrp_wrap = (
+            "powershell Invoke-Command -ComputerName {} -ScriptBlock {{ {} }}; exit"
+            " $LASTEXITCODE"
+        )
         runaspy = textwrap.dedent(
             """
         import sys
@@ -653,14 +650,14 @@ class RunAsTest(ModuleCase):
             os.remove(RUNAS_OUT)
         assert not os.path.exists(RUNAS_OUT)
         runaspy = SERVICE_SOURCE.format(repr(RUNAS_OUT), username, PASSWORD)
-        with io.open(RUNAS_PATH, "w", encoding="utf-8") as fp:
+        with salt.utils.files.fopen(RUNAS_PATH, "w", encoding="utf-8") as fp:
             fp.write(runaspy)
         ret = subprocess.call(["python.exe", RUNAS_PATH])
         self.assertEqual(ret, 0)
         win32serviceutil.StartService("test service")
         wait_for_service("test service")
         with salt.utils.files.fopen(RUNAS_OUT, "r") as fp:
-            ret = yaml.load(fp)
+            ret = salt.utils.yaml.safe_load(fp)
         assert ret["retcode"] == 1, ret
 
     @with_system_user(
@@ -671,14 +668,14 @@ class RunAsTest(ModuleCase):
             os.remove(RUNAS_OUT)
         assert not os.path.exists(RUNAS_OUT)
         runaspy = SERVICE_SOURCE.format(repr(RUNAS_OUT), username, "")
-        with io.open(RUNAS_PATH, "w", encoding="utf-8") as fp:
+        with salt.utils.files.fopen(RUNAS_PATH, "w", encoding="utf-8") as fp:
             fp.write(runaspy)
         ret = subprocess.call(["python.exe", RUNAS_PATH])
         self.assertEqual(ret, 0)
         win32serviceutil.StartService("test service")
         wait_for_service("test service")
         with salt.utils.files.fopen(RUNAS_OUT, "r") as fp:
-            ret = yaml.load(fp)
+            ret = salt.utils.yaml.safe_load(fp)
         assert ret["retcode"] == 1, ret
 
     @with_system_user(
@@ -693,14 +690,14 @@ class RunAsTest(ModuleCase):
             os.remove(RUNAS_OUT)
         assert not os.path.exists(RUNAS_OUT)
         runaspy = SERVICE_SOURCE.format(repr(RUNAS_OUT), username, PASSWORD)
-        with io.open(RUNAS_PATH, "w", encoding="utf-8") as fp:
+        with salt.utils.files.fopen(RUNAS_PATH, "w", encoding="utf-8") as fp:
             fp.write(runaspy)
         ret = subprocess.call(["python.exe", RUNAS_PATH])
         self.assertEqual(ret, 0)
         win32serviceutil.StartService("test service")
         wait_for_service("test service")
         with salt.utils.files.fopen(RUNAS_OUT, "r") as fp:
-            ret = yaml.load(fp)
+            ret = salt.utils.yaml.safe_load(fp)
         assert ret["retcode"] == 0, ret
 
     @with_system_user(
@@ -715,14 +712,14 @@ class RunAsTest(ModuleCase):
             os.remove(RUNAS_OUT)
         assert not os.path.exists(RUNAS_OUT)
         runaspy = SERVICE_SOURCE.format(repr(RUNAS_OUT), username, "")
-        with io.open(RUNAS_PATH, "w", encoding="utf-8") as fp:
+        with salt.utils.files.fopen(RUNAS_PATH, "w", encoding="utf-8") as fp:
             fp.write(runaspy)
         ret = subprocess.call(["python.exe", RUNAS_PATH])
         self.assertEqual(ret, 0)
         win32serviceutil.StartService("test service")
         wait_for_service("test service")
         with salt.utils.files.fopen(RUNAS_OUT, "r") as fp:
-            ret = yaml.load(fp)
+            ret = salt.utils.yaml.safe_load(fp)
         assert ret["retcode"] == 0, ret
 
     def test_runas_service_system_user(self):
@@ -730,12 +727,12 @@ class RunAsTest(ModuleCase):
             os.remove(RUNAS_OUT)
         assert not os.path.exists(RUNAS_OUT)
         runaspy = SERVICE_SOURCE.format(repr(RUNAS_OUT), "SYSTEM", "")
-        with io.open(RUNAS_PATH, "w", encoding="utf-8") as fp:
+        with salt.utils.files.fopen(RUNAS_PATH, "w", encoding="utf-8") as fp:
             fp.write(runaspy)
         ret = subprocess.call(["python.exe", RUNAS_PATH])
         self.assertEqual(ret, 0)
         win32serviceutil.StartService("test service")
         wait_for_service("test service")
         with salt.utils.files.fopen(RUNAS_OUT, "r") as fp:
-            ret = yaml.load(fp)
+            ret = salt.utils.yaml.safe_load(fp)
         assert ret["retcode"] == 0, ret
