@@ -4,21 +4,18 @@ Integration tests for salt-ssh py_versions
 import logging
 import shutil
 import subprocess
+import time
 
 import pytest
-from saltfactories.factories.daemons.container import ContainerFactory
 from saltfactories.utils import random_string
-from saltfactories.utils.ports import get_unused_localhost_port
 
-docker = pytest.importorskip("docker")
-from docker.errors import (  # isort:skip pylint: disable=3rd-party-module-not-gated,no-name-in-module
-    DockerException,
-)
+pytest.importorskip("docker")
 
 
 log = logging.getLogger(__name__)
 
 pytestmark = [
+    pytest.mark.slow_test,
     pytest.mark.skip_if_binaries_missing("dockerd"),
 ]
 
@@ -57,18 +54,6 @@ class Keys:
         shutil.rmtree(str(self.priv_path.parent), ignore_errors=True)
 
 
-@pytest.fixture(scope="module")
-def docker_client():
-    try:
-        client = docker.from_env()
-    except DockerException:
-        pytest.skip("Failed to get a connection to docker running on the system")
-    connectable = ContainerFactory.client_connectable(client)
-    if connectable is not True:  # pragma: nocover
-        pytest.skip(connectable)
-    return client
-
-
 @pytest.fixture(scope="module")
 def ssh_keys(tmp_path_factory):
     """
@@ -79,11 +64,34 @@ def ssh_keys(tmp_path_factory):
 
 
 @pytest.fixture(scope="module")
-def ssh_port():
+def ssh_docker_container(salt_factories, ssh_keys):
     """
-    Temporary ssh port fixture
+    Temporary docker container with python 3.6 and ssh enabled
     """
-    return get_unused_localhost_port()
+    container = salt_factories.get_container(
+        random_string("ssh-py_versions-"),
+        "dwoz1/cicd:ssh",
+        container_run_kwargs={
+            "ports": {
+                "22/tcp": None,
+            },
+            "environment": {
+                "SSH_USER": "centos",
+                "SSH_AUTHORIZED_KEYS": ssh_keys.pub,
+            },
+            "cap_add": "IPC_LOCK",
+        },
+        pull_before_start=True,
+        skip_on_pull_failure=True,
+        skip_if_docker_client_not_connectable=True,
+    )
+    with container.started() as factory:
+        yield factory
+
+
+@pytest.fixture(scope="module")
+def ssh_port(ssh_docker_container):
+    return ssh_docker_container.get_host_port_binding(22, protocol="tcp")
 
 
 @pytest.fixture(scope="module")
@@ -109,37 +117,28 @@ def salt_ssh_roster_file(ssh_port, ssh_keys, salt_master):
         yield roster_file
 
 
-@pytest.fixture(scope="module")
-def ssh_docker_container(salt_factories, docker_client, ssh_port, ssh_keys):
-    """
-    Temporary docker container with python 3.6 and ssh enabled
-    """
-    container = salt_factories.get_container(
-        random_string("ssh-py_versions-"),
-        "dwoz1/cicd:ssh",
-        docker_client=docker_client,
-        check_ports=[ssh_port],
-        container_run_kwargs={
-            "ports": {"22/tcp": ssh_port},
-            "environment": {"SSH_USER": "centos", "SSH_AUTHORIZED_KEYS": ssh_keys.pub},
-            "cap_add": "IPC_LOCK",
-        },
-    )
-    with container.started() as factory:
-        yield factory
-
-
 @pytest.fixture(scope="module")
 def salt_ssh_cli(salt_master, salt_ssh_roster_file, ssh_keys, ssh_docker_container):
     assert salt_master.is_running()
     assert ssh_docker_container.is_running()
-    return salt_master.get_salt_ssh_cli(
-        default_timeout=180,
+    ret = salt_master.salt_ssh_cli(
+        timeout=180,
         roster_file=salt_ssh_roster_file,
         target_host="localhost",
         client_key=str(ssh_keys.priv_path),
         base_script_args=["--ignore-host-keys"],
     )
+    # Ensure the container is up and communicating
+    # This reduces flakyness
+    start = time.time() + 15
+    while time.time() < start:
+        verify = ret.run("test.ping", minion_tgt="pyvertest")
+        if verify.returncode == 0:
+            break
+        time.sleep(2)
+    else:
+        pytest.fail("Could not establish connection with container")
+    return ret
 
 
 @pytest.mark.slow_test
@@ -148,6 +147,7 @@ def test_py36_target(salt_ssh_cli):
     Test that a python >3.6 master can salt ssh to a <3.6 target
     """
     ret = salt_ssh_cli.run("test.ping", minion_tgt="pyvertest")
-    assert ret.exitcode == 0
-    assert ret.json
-    assert ret.json is True
+    if "kex_exchange_identification" in ret.stdout:
+        pytest.skip("Container closed ssh connection, skipping for now")
+    assert ret.returncode == 0
+    assert ret.data is True
